[![Build Status](https://travis-ci.org/rhenanbartels/hrv.svg?branch=develop)](https://travis-ci.org/rhenanbartels/hrv)
[![codecov](https://codecov.io/gh/rhenanbartels/hrv/branch/develop/graph/badge.svg)](https://codecov.io/gh/rhenanbartels/hrv)
[![Current version at PyPI](https://img.shields.io/pypi/v/hrv.svg)](https://pypi.python.org/pypi/hrv)
[![Downloads per month on PyPI](https://img.shields.io/pypi/dm/hrv.svg)](https://pypi.python.org/pypi/hrv)
![Supported Python Versions](https://img.shields.io/pypi/pyversions/hrv.svg)
![Software status](https://img.shields.io/pypi/status/rows.svg)
[![License: LGPLv3](https://img.shields.io/pypi/l/hrv.svg)](https://github.com/rhenanbartels/hrv/blob/develop/LICENSE.md)


Pythonic package for Heart Rate Variability Analysis
===============================

version number: 0.2.7

author: Rhenan Bartels


![logo](docs/logo-small.png)

Overview
--------

**hrv** is a simple Python module that brings the most widely used
techniques to work with RRi series and Heart Rate Variability (HRV) analyses without losing the **Power** and **Flexibility**
of a native Python object and [numpy](http://www.numpy.org/) arrays.


For a more in-depth explanation of how hrv works, please [Read the documentation](https://hrv.readthedocs.io/en/latest/)
